@@ -24,6 +24,14 @@ class Imagick
 
     public function waveImage(float $amplitude, float $length): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function waveImageWithMethod(
+        float $amplitude,
+        float $length,
+        int $interpolate_method // INTERPOLATE_*
+    ): bool  {}
+#endif
+
     public function vignetteImage(float $black_point, float $white_point, int $x, int $y): bool  {}
 
     public function uniqueImageColors(): bool  {}
@@ -128,8 +136,17 @@ class Imagick
 #endif
 #endif
 
+#if MagickLibVersion >= 0x700
+    public function polaroidWithTextAndMethod(
+        ImagickDraw $settings,
+        float $angle,
+        string $caption,
+        int $method
+    ): bool {}
+#endif
+
 #if MagickLibVersion > 0x631
-    // TODO - ImagickDraw ....
+
     public function polaroidImage(ImagickDraw $settings, float $angle): bool  {}
 
     public function getImageProperty(string $name): string  {}
@@ -383,14 +400,14 @@ class Imagick
      *  $artifact example 'compose:args'
      *
      */
-    public function getImageArtifact(string $artifact): string  {}
+    public function getImageArtifact(string $artifact): string|null  {}
 
     /**
      * $artifact example 'compose:args'
      * $value example  "1,0,-0.5,0.5"
      *
      */
-    public function setImageArtifact(string $artifact, string $value): bool  {}
+    public function setImageArtifact(string $artifact, string|null $value): bool  {}
 
     public function deleteImageArtifact(string $artifact): bool  {}
 
@@ -558,6 +575,10 @@ class Imagick
 
     public function normalizeImage(int $channel = Imagick::CHANNEL_DEFAULT): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function oilPaintImageWithSigma(float $radius, float $sigma): bool  {}
+#endif
+
     public function oilPaintImage(float $radius): bool  {}
 
     public function posterizeImage(int $levels, bool $dither): bool  {}
@@ -660,8 +681,22 @@ class Imagick
 
     public function spreadImage(float $radius): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function spreadImageWithMethod(
+        float $radius,
+        int $interpolate_method // INTERPOLATE_*
+    ): bool  {}
+#endif
+
     public function swirlImage(float $degrees): bool  {}
 
+#if MagickLibVersion >= 0x700
+    public function swirlImageWithMethod(
+        float $degrees,
+        int $interpolate_method // INTERPOLATE_*
+    ): bool  {}
+#endif
+
     public function stripImage(): bool  {}
 
     public static function queryFormats(string $pattern = "*"): array  {}
@@ -941,6 +976,13 @@ class Imagick
 
     public function implodeImage(float $radius): bool  {}
 
+#if MagickLibVersion >= 0x700
+	public function implodeImageWithMethod(
+		float $radius,
+		int $pixel_interpolate_method // PixelInterpolateMethod
+	): bool  {}
+#endif
+
 #if MagickLibVersion >= 0x658
     // TODO MagickWand *magnitude_wand,MagickWand *phase_wand,
     public function inverseFourierTransformImage(Imagick $complement, bool $magnitude): bool  {}
@@ -1488,4 +1530,120 @@ proto bool Imagick::setImageBluePrimary(float x, float y, float z) */
 #if IM_HAVE_IMAGICK_WHITEBALANCEIMAGE
 	public function whiteBalanceImage(): bool {}
 #endif
+
+#if IM_HAVE_IMAGICK_DELETE_OPTION
+	public function deleteOption(string $option): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_BACKGROUND_COLOR
+	public function getBackgroundColor(): ImagickPixel {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_IMAGE_ARTIFACTS
+	/**
+	 * @return string[]
+	 */
+	public function getImageArtifacts(string $pattern = "*"): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_IMAGE_DISTORTIONS
+
+	/**
+	 * metric - MetricType_
+	 * @return float[]
+	 */
+//	public function getImageDistortions(int $metric): array{}
+//    for (j=0; j <= MaxPixelChannels; j++)
+//      distortion[j]+=channel_distortion[j];
+//	Use MagickRelinquishMemory() to free the metrics when you are done with them.
+#endif
+
+#if IM_HAVE_IMAGICK_GET_IMAGE_KURTOSIS
+
+	/**
+	 * return [kurtosis:float,skewness: float]
+	 */
+	public function getImageKurtosis(): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_IMAGE_MEAN
+	/**
+	 * return [$mean, $standard_deviation]
+	 */
+	public function getImageMean(): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_IMAGE_RANGE
+	/**
+	 * return [minima, float $maxima]
+	 */
+	public function getImageRange(): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_INTERPOLATE_METHOD
+	/**
+	 * return int - PixelInterpolateMethod
+	 */
+	public function getInterpolateMethod(): int {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_OPTIONS
+	/**
+	 * return string[]
+	 */
+	public function getOptions(string $pattern = "*"): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_ORIENTATION
+	/**
+	 * return int OrientationType
+	 */
+	public function getOrientation(): int {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_RESOLUTION
+	/**
+	 * return [x: float, y: float]
+	 */
+	public function getResolution(): array {}
+#endif
+
+#if IM_HAVE_IMAGICK_GET_TYPE
+	/**
+	 * return ImageType
+	 */
+	public function getType(): int {}
+#endif
+
+#if IM_HAVE_IMAGICK_POLYNOMIAL_IMAGE
+	//%    o number_terms: the number of terms in the list.  The actual list length
+	//%      is 2 x number_terms + 1 (the constant).
+	public function polynomialImage(array $terms): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_SET_DEPTH
+	public function setDepth(int $depth): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_SET_EXTRACT
+	//%  MagickSetExtract() sets the extract geometry before you read or write an
+	//%  image file.  Use it for inline cropping (e.g. 200x200+0+0) or resizing
+	//%  (e.g.200x200).
+	public function setExtract(string $geometry): bool {}
+#endif
+
+#if IM_HAVE_IMAGICK_SET_INTERPOLATE_METHOD
+/**
+ * int $method - PixelInterpolateMethod
+ */
+	public function setInterpolateMethod(int $method): bool{}
+#endif
+
+#if IM_HAVE_IMAGICK_SET_ORIENTATION
+	/**
+	 * $orientation - OrientationType
+	 */
+	public function setOrientation(int $orientation): bool {}
+#endif
+
 }
