@@ -30,8 +30,10 @@
 #include "ext/standard/php_smart_str.h"
 #endif
 
-/* For the countable interface */
+#if PHP_VERSION_ID < 70200
+///* For the countable interface */
 #include "ext/spl/spl_iterators.h"
+#endif
 
 #include "shim_php7_to_php8.h"
 
@@ -1194,7 +1196,9 @@ PHP_MINFO_FUNCTION(imagick)
 
 PHP_MSHUTDOWN_FUNCTION(imagick)
 {
+#if !HAVE_OMP_PAUSE_RESOURCE_ALL
     int i;
+#endif
 
 // This suppresses an 'unused parameter' warning.
 	(void)type;
